@@ -16,30 +16,38 @@ import sys
 
 from shade import _log
 
-log = _log.setup_logging(__name__)
-
 
 class OpenStackCloudException(Exception):
 
+    log_inner_exceptions = False
+
     def __init__(self, message, extra_data=None):
         args = [message]
         if extra_data:
             args.append(extra_data)
         super(OpenStackCloudException, self).__init__(*args)
         self.extra_data = extra_data
-        self._inner_exception = sys.exc_info()
-        if self._inner_exception and self._inner_exception[1]:
-            log.error(message, exc_info=self._inner_exception)
+        self.inner_exception = sys.exc_info()
+        self.orig_message = message
+
+    def log_error(self, logger=None):
+        if not logger:
+            logger = _log.setup_logging(__name__)
+        if self.inner_exception and self.inner_exception[1]:
+            logger.error(self.orig_message, exc_info=self.inner_exception)
 
     def __str__(self):
         message = Exception.__str__(self)
         if self.extra_data is not None:
             message = "%s (Extra: %s)" % (message, self.extra_data)
-        if (self._inner_exception and self._inner_exception[1]
-                and hasattr(self._inner_exception[1], 'message')):
+        if (self.inner_exception and self.inner_exception[1]
+                and not self.orig_message.endswith(
+                    str(self.inner_exception[1]))):
             message = "%s (Inner Exception: %s)" % (
                 message,
-                self._inner_exception[1].message)
+                str(self.inner_exception[1]))
+        if self.log_inner_exceptions:
+            self.log_error()
         return message
 
 
